==> openGion6.8.0.0_dev.zip: uap/webapps/ge/db/POSTGRES/sql/install/01_TABLE/GE51S.sql <==
/****************************************************************************/
/* GE51 ( 帳票ﾃﾞｰﾀﾃｰﾌﾞﾙ )                                                   */
/*                                                                          */
/* Created : 2017/01/05 15:19:07                                            */
/****************************************************************************/

CREATE TABLE GE51 (
   SYSTEM_ID    VARCHAR (   10 )                    NOT NULL            /*  10 ｼｽﾃﾑID   */
 , YKNO         INTEGER                 DEFAULT 0   NOT NULL            /*  20 要求NO   */
 , EDNO         INTEGER                 DEFAULT 0   NOT NULL            /*  30 枝番     */
 , KBTEXT       VARCHAR (    1 )                    NOT NULL            /*  40 ﾃｷｽﾄ区分 */
 , TEXT_DATA    VARCHAR ( 4000 )                                        /*  50 ﾃｷｽﾄ     */
 , FGJ          VARCHAR (    1 )        DEFAULT '1' NOT NULL            /* 810 状態ﾌﾗｸﾞ */
 , DYSET        VARCHAR (   14 )                                        /* 820 登録日時 */
 , PGSET        VARCHAR (   10 )                                        /* 830 作成PG   */
 , PGPSET       VARCHAR (   10 )                                        /* 840 作成親PG */
 , USRSET       VARCHAR (   10 )                                        /* 850 作成社員 */
 , DYUPD        VARCHAR (   14 )                                        /* 860 更新日時 */
 , PGUPD        VARCHAR (   10 )                                        /* 870 更新PG   */
 , PGPUPD       VARCHAR (   10 )                                        /* 880 更新親PG */
 , USRUPD       VARCHAR (   10 )                                        /* 890 更新者   */
);

==> openGion7.2.4.0_dev.zip: uap/webapps/ge/db/POSTGRES/sql/install/01_TABLE/GE51S.sql <==
/****************************************************************************/
/* GE51 ( 帳票ﾃﾞｰﾀﾃｰﾌﾞﾙ )                                                   */
/*                                                                          */
/* Created : 2018/09/28 16:03:31                                            */
/****************************************************************************/

CREATE TABLE GE51 (
   SYSTEM_ID    VARCHAR (   10 )                    NOT NULL            /*  10 ｼｽﾃﾑID   */
 , YKNO         INTEGER                 DEFAULT 0   NOT NULL            /*  20 要求NO   */
 , EDNO         INTEGER                 DEFAULT 0   NOT NULL            /*  30 枝番     */
 , KBTEXT       VARCHAR (    1 )                    NOT NULL            /*  40 ﾃｷｽﾄ区分 */
 , TEXT_DATA    VARCHAR ( 4000 )                                        /*  50 ﾃｷｽﾄ     */
 , FGJ          VARCHAR (    1 )        DEFAULT '1' NOT NULL            /* 810 状態ﾌﾗｸﾞ */
 , DYSET        VARCHAR (   14 )                                        /* 820 登録日時 */
 , PGSET        VARCHAR (   10 )                                        /* 830 作成PG   */
 , PGPSET       VARCHAR (   10 )                                        /* 840 作成親PG */
 , USRSET       VARCHAR (   10 )                                        /* 850 作成者   */
 , DYUPD        VARCHAR (   14 )                                        /* 860 更新日時 */
 , PGUPD        VARCHAR (   10 )                                        /* 870 更新PG   */
 , PGPUPD       VARCHAR (   10 )                                        /* 880 更新親PG */
 , USRUPD       VARCHAR (   10 )                                        /* 890 更新者   */
);
